#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include "qrcode.h"

#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64
#define OLED_RESET    -1
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

const char* ssid = "Your_SSID";
const char* password = "Your_PASSWORD";
ESP8266WebServer server(80);

String qrText = "Hello, ESP8266!";

void generateQRCode(String text) {
    display.clearDisplay();
    QRCode qrcode;
    uint8_t qrcodeData[qrcode_getBufferSize(3)];
    qrcode_initText(&qrcode, qrcodeData, 3, 0, text.c_str());
    
    int scale = 2;
    int offsetX = (SCREEN_WIDTH - qrcode.size * scale) / 2;
    int offsetY = (SCREEN_HEIGHT - qrcode.size * scale) / 2;
    
    for (uint8_t y = 0; y < qrcode.size; y++) {
        for (uint8_t x = 0; x < qrcode.size; x++) {
            if (qrcode_getModule(&qrcode, x, y)) {
                display.fillRect(offsetX + x * scale, offsetY + y * scale, scale, scale, SSD1306_WHITE);
            }
        }
    }
    display.display();
}

void handleRoot() {
    server.send(200, "text/html", "<form action='/set' method='POST'><input type='text' name='text'><input type='submit' value='Generate QR'></form>");
}

void handleSet() {
    if (server.hasArg("text")) {
        qrText = server.arg("text");
        generateQRCode(qrText);
    }
    server.sendHeader("Location", "/");
    server.send(303);
}

void setup() {
    Serial.begin(115200);
    
    if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
        Serial.println(F("SSD1306 allocation failed"));
        for (;;);
    }
    display.clearDisplay();
    display.display();
    
    WiFi.begin(ssid, password);
    while (WiFi.status() != WL_CONNECTED) {
        delay(500);
        Serial.print(".");
    }
    
    Serial.println("\nWiFi connected");
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());  // Вивід IP-адреси в монітор порту
    
    server.on("/", handleRoot);
    server.on("/set", HTTP_POST, handleSet);
    server.begin();
    
    generateQRCode(qrText);
}

void loop() {
    server.handleClient();
}
